@@ -1,6 +1,6 @@
-# This file is part of the Frescobaldi project, http://www.frescobaldi.org/
+# This file is part of python-ly, https://pypi.python.org/pypi/python-ly
 #
-# Copyright (c) 2008 - 2014 by Wilbert Berendsen
+# Copyright (c) 2008 - 2015 by Wilbert Berendsen
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -42,19 +42,19 @@ re_dot = r"\."
 re_scaling = r"\*[\t ]*\d+(/\d+)?"
 
 # an identifier allowing letters and single hyphens inbetween
-re_identifier = r"[^\W\d_]+(-[^\W\d_]+)*"
+re_identifier = r"[^\W\d_]+([_-][^\W\d_]+)*"
 
 # the lookahead pattern for the end of an identifier (ref)
-re_identifier_end = r"(?!-?[^\W\d])"
+re_identifier_end = r"(?![_-]?[^\W\d])"
 
 
 class Identifier(_token.Token):
-    """A variable name, like "some-variable"."""
+    """A variable name, like ``some-variable``."""
     rx = r"(?<![^\W\d])" + re_identifier + re_identifier_end
 
 
 class IdentifierRef(_token.Token):
-    """A reference to an identifier, e.g. "\some-variable"."""
+    r"""A reference to an identifier, e.g. ``\some-variable``."""
     rx = r"\\" + re_identifier + re_identifier_end
 
 
@@ -139,7 +139,7 @@ class StringQuoteEscape(_token.Character):
 
 
 class MusicItem(_token.Token):
-    """A note, rest, spacer, \skip or q."""
+    r"""A note, rest, spacer, ``\skip`` or ``q``."""
 
     
 class Skip(MusicItem):
@@ -865,7 +865,7 @@ class ErrorInChord(Error):
     
 
 class Name(UserVariable):
-    """A variable name without \\ prefix."""
+    r"""A variable name without \ prefix."""
     
 
 class EqualSign(_token.Token):
@@ -1032,7 +1032,7 @@ class ExpectMusicList(FallthroughParser, ParseLilyPond):
         
 
 class ParseScore(ParseLilyPond):
-    """Parses the expression after \score {, leaving at } """
+    r"""Parses the expression after ``\score {``, leaving at ``}`` """
     items = (
         CloseBracket,
         Header, Layout, Midi, With,
@@ -1044,7 +1044,7 @@ class ExpectScore(ExpectOpenBracket):
             
 
 class ParseBook(ParseLilyPond):
-    """Parses the expression after \book {, leaving at } """
+    r"""Parses the expression after ``\book {``, leaving at ``}`` """
     items = (
         CloseBracket,
         MarkupStart, MarkupLines, MarkupList,
@@ -1060,7 +1060,7 @@ class ExpectBook(ExpectOpenBracket):
 
 
 class ParseBookPart(ParseLilyPond):
-    """Parses the expression after \bookpart {, leaving at } """
+    r"""Parses the expression after ``\bookpart {``, leaving at ``}`` """
     items = (
         CloseBracket,
         MarkupStart, MarkupLines, MarkupList,
@@ -1074,7 +1074,7 @@ class ExpectBookPart(ExpectOpenBracket):
 
 
 class ParsePaper(ParseLilyPond):
-    """Parses the expression after \paper {, leaving at } """
+    r"""Parses the expression after ``\paper {``, leaving at ``}`` """
     items = base_items + (
         CloseBracket,
         MarkupStart, MarkupLines, MarkupList,
@@ -1092,7 +1092,7 @@ class ExpectPaper(ExpectOpenBracket):
 
 
 class ParseHeader(ParseLilyPond):
-    """Parses the expression after \header {, leaving at } """
+    r"""Parses the expression after ``\header {``, leaving at ``}`` """
     items = (
         CloseBracket,
         MarkupStart, MarkupLines, MarkupList,
@@ -1108,7 +1108,7 @@ class ExpectHeader(ExpectOpenBracket):
         
 
 class ParseLayout(ParseLilyPond):
-    """Parses the expression after \layout {, leaving at } """
+    r"""Parses the expression after ``\layout {``, leaving at ``}`` """
     items = base_items + (
         CloseBracket,
         LayoutContext,
@@ -1128,7 +1128,7 @@ class ExpectLayout(ExpectOpenBracket):
         
 
 class ParseMidi(ParseLilyPond):
-    """Parses the expression after \midi {, leaving at } """
+    r"""Parses the expression after ``\midi {``, leaving at ``}`` """
     items = base_items + (
         CloseBracket,
         LayoutContext,
@@ -1148,7 +1148,7 @@ class ExpectMidi(ExpectOpenBracket):
 
 
 class ParseWith(ParseLilyPond):
-    """Parses the expression after \with {, leaving at } """
+    r"""Parses the expression after ``\with {``, leaving at ``}`` """
     items = (
         CloseBracket,
         ContextName,
@@ -1164,7 +1164,7 @@ class ExpectWith(ExpectOpenBracket):
         
 
 class ParseContext(ParseLilyPond):
-    """Parses the expression after (\layout {) \context {, leaving at } """
+    r"""Parses the expression after (``\layout {``) ``\context {``, leaving at ``}`` """
     items = (
         CloseBracket,
         BackSlashedContextName,
@@ -1186,7 +1186,7 @@ class ParseMusic(ParseLilyPond):
     
 
 class ParseChord(ParseMusic):
-    """LilyPond inside chords < >"""
+    """LilyPond inside chords ``< >``"""
     items = music_chord_items
 
 
@@ -1275,7 +1275,7 @@ class ParseOverride(ParseLilyPond):
 
 
 class ParseRevert(FallthroughParser):
-    # parse the arguments of \revert
+    r"""parse the arguments of ``\revert``"""
     # allow both the old scheme syntax but also the dotted 2.18+ syntax
     # allow either a dot between the GrobName and the property path or not
     # correctly fall through when one property path has been parsed
@@ -1449,7 +1449,7 @@ class ParseInputMode(ParseLilyPond):
     
     
 class ParseLyricMode(ParseInputMode):
-    """Parser for \\lyrics, \\lyricmode, \\addlyrics, etc."""
+    r"""Parser for ``\lyrics``, ``\lyricmode``, ``\addlyrics``, etc."""
     items = base_items + (
         CloseBracket,
         CloseSimultaneous,
@@ -1480,7 +1480,7 @@ class ExpectLyricMode(ExpectMusicList):
 
 
 class ParseChordMode(ParseInputMode, ParseMusic):
-    """Parser for \\chords and \\chordmode."""
+    r"""Parser for ``\chords`` and ``\chordmode``."""
     items = (
         OpenBracket,
         OpenSimultaneous,
@@ -1499,7 +1499,7 @@ class ExpectChordMode(ExpectMusicList):
         
 
 class ParseNoteMode(ParseMusic):
-    """Parser for \\notes and \\notemode. Same as Music itself."""
+    r"""Parser for ``\notes`` and ``\notemode``. Same as Music itself."""
 
 
 class ExpectNoteMode(ExpectMusicList):
@@ -1507,7 +1507,7 @@ class ExpectNoteMode(ExpectMusicList):
         
 
 class ParseDrumMode(ParseInputMode, ParseMusic):
-    """Parser for \\drums and \\drummode."""
+    r"""Parser for ``\drums`` and ``\drummode``."""
     # TODO: implement items (see ParseChordMode)
 
 
@@ -1516,7 +1516,7 @@ class ExpectDrumMode(ExpectMusicList):
         
 
 class ParseFigureMode(ParseInputMode, ParseMusic):
-    """Parser for \\figures and \\figuremode."""
+    r"""Parser for ``\figures`` and ``\figuremode``."""
     items = base_items + (
         CloseBracket,
         CloseSimultaneous,
@@ -1530,7 +1530,7 @@ class ParseFigureMode(ParseInputMode, ParseMusic):
 
 
 class ParseFigure(Parser):
-    """Parse inside < > in figure mode."""
+    """Parse inside ``< >`` in figure mode."""
     items = base_items + (
         FigureEnd,
         FigureBracket,
